# svVascularize


![Version](https://img.shields.io/badge/version-0.0.31-blue)
![Platform](https://img.shields.io/badge/platform-macOS%20|%20linux%20|%20windows-blue)
![Latest Release](https://img.shields.io/github/v/release/SimVascular/svVascularize?label=latest)
[![codecov](https://codecov.io/github/SimVascular/svVascularize/graph/badge.svg)](https://codecov.io/github/SimVascular/svVascularize)
[![DOI](https://img.shields.io/badge/DOI-green)]()

<p align="left">
The svVascularize (svv) is an open-source API for automated vascular generation and multi-fidelity hemodynamic simulation
written in Python. Often small-caliber vessels are difficult or infeasible to obtain from experimental data sources 
despite playing important roles in blood flow regulation and cell microenvironments. svVascularize aims to provide tissue 
engineers and computational hemodynamic scientists with de novo vasculature that can easily be applied in 
biomanufacturing applications or computational fluid dynamic (CFD) analysis.
</p>

* **Website:** 
* **PyPi:** 
* **Source code:**
